@@ -1,6 +1,6 @@
 //! Server module
 use std::fs::File;
-use std::io::{self, Read};
+use std::io::{self, Error as IoError, ErrorKind, Read};
 use std::net::{IpAddr, SocketAddr as StdSocketAddr, ToSocketAddrs};
 use std::path::PathBuf;
 use std::pin::Pin;
@@ -14,6 +14,8 @@ use tokio::io::{AsyncRead, AsyncWrite, ReadBuf};
 use crate::addr::SocketAddr;
 use crate::transport::Transport;
 
+#[cfg(feature = "acme")]
+pub mod acme;
 #[cfg(feature = "native-tls")]
 pub mod native_tls;
 #[cfg(feature = "rustls")]
@@ -21,6 +23,8 @@ pub mod rustls;
 #[cfg(unix)]
 pub mod unix;
 
+#[cfg(feature = "acme")]
+pub use acme::AcmeListener;
 #[cfg(feature = "native-tls")]
 pub use native_tls::NativeTlsListener;
 #[cfg(feature = "rustls")]
@@ -126,23 +130,19 @@ where
     B::Conn: Transport,
 {
     type Conn = JoinedStream<A::Conn, B::Conn>;
-    type Error = io::Error;
+    type Error = IoError;
 
     fn poll_accept(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Self::Conn, Self::Error>>> {
         let pin = self.get_mut();
         if fastrand::bool() {
             match Pin::new(&mut pin.a).poll_accept(cx) {
                 Poll::Ready(Some(result)) => Poll::Ready(Some(
-                    result
-                        .map(JoinedStream::A)
-                        .map_err(|_| io::Error::from(io::ErrorKind::Other)),
+                    result.map(JoinedStream::A).map_err(|_| IoError::from(ErrorKind::Other)),
                 )),
                 Poll::Ready(None) => Poll::Ready(None),
                 Poll::Pending => match Pin::new(&mut pin.b).poll_accept(cx) {
                     Poll::Ready(Some(result)) => Poll::Ready(Some(
-                        result
-                            .map(JoinedStream::B)
-                            .map_err(|_| io::Error::from(io::ErrorKind::Other)),
+                        result.map(JoinedStream::B).map_err(|_| IoError::from(ErrorKind::Other)),
                     )),
                     Poll::Ready(None) => Poll::Ready(None),
                     Poll::Pending => Poll::Pending,
@@ -151,16 +151,12 @@ where
         } else {
             match Pin::new(&mut pin.b).poll_accept(cx) {
                 Poll::Ready(Some(result)) => Poll::Ready(Some(
-                    result
-                        .map(JoinedStream::B)
-                        .map_err(|_| io::Error::from(io::ErrorKind::Other)),
+                    result.map(JoinedStream::B).map_err(|_| IoError::from(ErrorKind::Other)),
                 )),
                 Poll::Ready(None) => Poll::Ready(None),
                 Poll::Pending => match Pin::new(&mut pin.a).poll_accept(cx) {
                     Poll::Ready(Some(result)) => Poll::Ready(Some(
-                        result
-                            .map(JoinedStream::A)
-                            .map_err(|_| io::Error::from(io::ErrorKind::Other)),
+                        result.map(JoinedStream::A).map_err(|_| IoError::from(ErrorKind::Other)),
                     )),
                     Poll::Ready(None) => Poll::Ready(None),
                     Poll::Pending => Poll::Pending,
@@ -191,7 +187,7 @@ impl TcpListener {
 impl Listener for TcpListener {}
 impl Accept for TcpListener {
     type Conn = AddrStream;
-    type Error = io::Error;
+    type Error = IoError;
 
     fn poll_accept(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Self::Conn, Self::Error>>> {
         Pin::new(&mut self.get_mut().incoming).poll_accept(cx)
@@ -256,10 +252,73 @@ impl LazyFile {
 }
 impl Read for LazyFile {
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
-        self.lazy_read(buf).map_err(|err| {
-            let kind = err.kind();
-            tracing::error!(path = ?self.path, error = ?err, "error reading file");
-            io::Error::new(kind, format!("error reading file ({:?}): {}", self.path.display(), err))
+        self.lazy_read(buf).map_err(|e| {
+            let kind = e.kind();
+            tracing::error!(path = ?self.path, error = ?e, "error reading file");
+            IoError::new(kind, format!("error reading file ({:?}): {}", self.path.display(), e))
         })
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use futures_util::{Stream, StreamExt};
+    use tokio::io::{AsyncReadExt, AsyncWriteExt};
+    use tokio::net::TcpStream;
+
+    use super::*;
+
+    impl Stream for TcpListener {
+        type Item = Result<AddrStream, IoError>;
+        fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+            self.poll_accept(cx)
+        }
+    }
+
+    impl<A, B> Stream for JoinedListener<A, B>
+    where
+        A: Accept + Send + Unpin + 'static,
+        B: Accept + Send + Unpin + 'static,
+        A::Conn: Transport,
+        B::Conn: Transport,
+    {
+        type Item = Result<JoinedStream<A::Conn, B::Conn>, IoError>;
+        fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+            self.poll_accept(cx)
+        }
+    }
+
+    #[tokio::test]
+    async fn test_tcp_listener() {
+        let addr = std::net::SocketAddr::from(([127, 0, 0, 1], 6878));
+
+        let mut listener = TcpListener::bind(addr);
+        tokio::spawn(async move {
+            let mut stream = TcpStream::connect(addr).await.unwrap();
+            stream.write_i32(150).await.unwrap();
+        });
+
+        let mut stream = listener.next().await.unwrap().unwrap();
+        assert_eq!(stream.read_i32().await.unwrap(), 150);
+    }
+
+    #[tokio::test]
+    async fn test_joined_listener() {
+        let addr1 = std::net::SocketAddr::from(([127, 0, 0, 1], 6978));
+        let addr2 = std::net::SocketAddr::from(([127, 0, 0, 1], 6979));
+
+        let mut listener = TcpListener::bind(addr1).join(TcpListener::bind(addr2));
+        tokio::spawn(async move {
+            let mut stream = TcpStream::connect(addr1).await.unwrap();
+            stream.write_i32(50).await.unwrap();
+
+            let mut stream = TcpStream::connect(addr2).await.unwrap();
+            stream.write_i32(100).await.unwrap();
+        });
+        let mut stream = listener.next().await.unwrap().unwrap();
+        let first = stream.read_i32().await.unwrap();
+        let mut stream = listener.next().await.unwrap().unwrap();
+        let second = stream.read_i32().await.unwrap();
+        assert_eq!(first + second, 150);
+    }
+}
