@@ -1,6 +1,7 @@
 //! tls module
+use std::fmt::{self, Formatter};
 use std::future::Future;
-use std::io::{self, BufReader, Cursor, Read};
+use std::io::{self, BufReader, Cursor, Error as IoError, Read};
 use std::path::Path;
 use std::pin::Pin;
 use std::sync::Arc;
@@ -13,7 +14,7 @@ use hyper::server::conn::{AddrIncoming, AddrStream};
 use pin_project_lite::pin_project;
 use rustls_pemfile::{self, pkcs8_private_keys, rsa_private_keys};
 use thiserror::Error;
-use tokio::io::{AsyncRead, AsyncWrite, ReadBuf};
+use tokio::io::{AsyncRead, AsyncWrite, ErrorKind, ReadBuf};
 pub use tokio_rustls::rustls::server::ServerConfig;
 use tokio_rustls::rustls::server::{AllowAnyAnonymousOrAuthenticatedClient, AllowAnyAuthenticatedClient, NoClientAuth};
 use tokio_rustls::rustls::{Certificate, Error as RustlsError, PrivateKey, RootCertStore};
@@ -31,7 +32,7 @@ pub enum Error {
     Hyper(hyper::Error),
     /// An IO error
     #[error("io error")]
-    Io(io::Error),
+    Io(IoError),
     /// An Error parsing the Certificate
     #[error("certificate parse error")]
     CertParseError,
@@ -68,8 +69,8 @@ pub struct RustlsConfig {
     ocsp_resp: Vec<u8>,
 }
 
-impl std::fmt::Debug for RustlsConfig {
-    fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result {
+impl fmt::Debug for RustlsConfig {
+    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
         f.debug_struct("RustlsConfig").finish()
     }
 }
@@ -341,14 +342,12 @@ where
     C::Item: Into<Arc<ServerConfig>>,
 {
     type Conn = RustlsStream;
-    type Error = io::Error;
+    type Error = IoError;
 
     fn poll_accept(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Self::Conn, Self::Error>>> {
         let this = self.project();
-        if let Poll::Ready(result) = this.config_stream.poll_next(cx) {
-            if let Some(config) = result {
-                *this.server_config = Some(config.into());
-            }
+        if let Poll::Ready(Some(config)) = this.config_stream.poll_next(cx) {
+            *this.server_config = Some(config.into());
         }
         if let Some(server_config) = &this.server_config {
             match ready!(Pin::new(this.incoming).poll_accept(cx)) {
@@ -357,24 +356,13 @@ where
                 None => Poll::Ready(None),
             }
         } else {
-            Poll::Ready(Some(Err(io::Error::new(
-                io::ErrorKind::Other,
+            Poll::Ready(Some(Err(IoError::new(
+                ErrorKind::Other,
                 "faild to load rustls server config",
             ))))
         }
     }
 }
-impl<C> Future for RustlsListener<C>
-where
-    C: Stream,
-    C::Item: Into<Arc<ServerConfig>>,
-{
-    type Output = Option<Result<RustlsStream, io::Error>>;
-
-    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
-        self.poll_accept(cx)
-    }
-}
 
 enum RustlsState {
     Handshaking(tokio_rustls::Accept<AddrStream>),
@@ -456,6 +444,7 @@ impl AsyncWrite for RustlsStream {
 
 #[cfg(test)]
 mod tests {
+    use futures_util::{Stream, StreamExt};
     use tokio::io::{AsyncReadExt, AsyncWriteExt};
     use tokio::net::TcpStream;
     use tokio_rustls::rustls::{ClientConfig, ServerName};
@@ -463,11 +452,21 @@ mod tests {
 
     use super::*;
 
+    impl<C> Stream for RustlsListener<C>
+    where
+        C: Stream,
+        C::Item: Into<Arc<ServerConfig>>,
+    {
+        type Item = Result<RustlsStream, IoError>;
+        fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+            self.poll_accept(cx)
+        }
+    }
     #[test]
     fn test_file_cert_key() {
         RustlsConfig::new()
-            .with_key_path("../examples/certs/end.rsa")
-            .with_cert_path("../examples/certs/end.cert")
+            .with_key_path("certs/end.rsa")
+            .with_cert_path("certs/end.cert")
             .build_server_config()
             .unwrap();
     }
@@ -475,16 +474,16 @@ mod tests {
     #[tokio::test]
     async fn test_rustls_listener() {
         let addr = std::net::SocketAddr::from(([127, 0, 0, 1], 7978));
-        let listener = RustlsListener::with_rustls_config(
+        let mut listener = RustlsListener::with_rustls_config(
             RustlsConfig::new()
-                .with_key_path("../examples/certs/end.rsa")
-                .with_cert_path("../examples/certs/end.cert"),
+                .with_key_path("certs/end.rsa")
+                .with_cert_path("certs/end.cert"),
         )
         .bind(addr);
 
         tokio::spawn(async move {
             let stream = TcpStream::connect(addr).await.unwrap();
-            let trust_anchor = include_bytes!("../../../examples/certs/end.chain");
+            let trust_anchor = include_bytes!("../../certs/end.chain");
             let client_config = ClientConfig::builder()
                 .with_safe_defaults()
                 .with_root_certificates(read_trust_anchor(Box::new(trust_anchor.as_slice())).unwrap())
@@ -497,7 +496,7 @@ mod tests {
             tls_stream.write_i32(518).await.unwrap();
         });
 
-        let mut stream = listener.await.unwrap().unwrap();
+        let mut stream = listener.next().await.unwrap().unwrap();
         assert_eq!(stream.read_i32().await.unwrap(), 518);
     }
 }
