@@ -37,6 +37,7 @@ where
     {
         HyperServer::builder(self.listener).serve(service.into()).await
     }
+
     /// Serve with graceful shutdown signal.
     ///
     /// # Example
@@ -48,7 +49,7 @@ where
     ///
     /// #[fn_handler]
     /// async fn hello_world(res: &mut Response) {
-    ///     res.render(Text::Plain("Hello World!");
+    ///     res.render("Hello World!");
     /// }
     ///
     /// #[tokio::main]
@@ -112,7 +113,7 @@ mod tests {
         }
         let router = Router::new().get(hello_world).push(Router::with_path("json").get(json));
 
-        tokio::task::spawn(async {
+        let server = tokio::task::spawn(async {
             Server::new(TcpListener::bind(([0, 0, 0, 0], 7979))).serve(router).await;
         });
 
@@ -178,5 +179,6 @@ mod tests {
             .await
             .unwrap();
         assert!(result.contains("<code>404</code>"));
+        server.abort();
     }
 }
